==> tensorforce-0.3.4.tar.gz: tensorforce-0.3.4/tensorforce/tests/test_dqn_agent.py <==
# Copyright 2017 reinforce.io. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

from __future__ import absolute_import
from __future__ import print_function
from __future__ import division

import unittest

from tensorforce.tests.base_agent_test import BaseAgentTest
from tensorforce.agents import DQNAgent


class TestDQNAgent(BaseAgentTest, unittest.TestCase):

    agent = DQNAgent
    deterministic = True

    config = dict(
        memory=dict(
            type='replay',
            capacity=1000
        ),
        optimizer=dict(
            type="adam",
            learning_rate=0.002
        ),
        # Comment in to test exploration types
        # explorations_spec=dict(
        #     type="epsilon_decay",
        #     initial_epsilon=1.0,
        #     final_epsilon=0.1,
        #     timesteps=10
        # ),
        # explorations_spec=dict(
        #     type="epsilon_anneal",
        #     initial_epsilon=1.0,
        #     final_epsilon=0.1,
        #     timesteps=10
        # ),
        repeat_update=4,
        batch_size=32,
        first_update=64,
        target_sync_frequency=10
    )

    exclude_float = True
    exclude_bounded = True

    multi_config = dict(
        memory=dict(
            type='replay',
            capacity=1000
        ),
        optimizer=dict(
            type="adam",
            learning_rate=0.01
        ),
        repeat_update=1,
        batch_size=16,
        first_update=16,
        target_sync_frequency=10
    )

==> tensorforce-0.4.0.tar.gz: tensorforce-0.4.0/tensorforce/tests/test_dqn_agent.py <==
# Copyright 2017 reinforce.io. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

from __future__ import absolute_import
from __future__ import print_function
from __future__ import division

import unittest

from tensorforce.tests.base_agent_test import BaseAgentTest
from tensorforce.agents import DQNAgent


class TestDQNAgent(BaseAgentTest, unittest.TestCase):

    agent = DQNAgent
    config = dict(
        update_mode=dict(
            unit='timesteps',
            batch_size=8,
            frequency=8
        ),
        memory=dict(
            type='replay',
            include_next_states=True,
            capacity=100
        ),
        # memory=dict(
        #     type='prioritized_replay',
        #     include_next_states=True,
        #     buffer_size=100,
        #     capacity=1000
        # ),
        optimizer=dict(
            type='adam',
            learning_rate=1e-2
        ),
        states_preprocessing=[
            dict(type='running_standardize'),
            dict(type='sequence')
        ],
        target_sync_frequency=10,
        # Comment in to test exploration types
        # actions_exploration_spec=dict(
        #     type="epsilon_decay",
        #     initial_epsilon=1.0,
        #     final_epsilon=0.1,
        #     timesteps=10
        # ),
        # actions_exploration_spec=dict(
        #     type="epsilon_anneal",
        #     initial_epsilon=1.0,
        #     final_epsilon=0.1,
        #     timesteps=10
        # )
    )

    exclude_float = True
    exclude_bounded = True
